@@ -75,14 +75,14 @@ Future <- function(expr = NULL, envir = parent.frame(), substitute = FALSE, glob
   }
 
   if (!is.null(globals)) {
-    stopifnot(is.list(globals),
+    stop_if_not(is.list(globals),
               length(globals) == 0 || inherits(globals, "Globals"))
   }
 
   if (!is.null(packages)) {
-    stopifnot(is.character(packages))
+    stop_if_not(is.character(packages))
     packages <- unique(packages)
-    stopifnot(!anyNA(packages), all(nzchar(packages)))
+    stop_if_not(!anyNA(packages), all(nzchar(packages)))
   }
 
   args <- list(...)
@@ -284,8 +284,12 @@ result <- function(...) UseMethod("result")
 #' @export
 #' @keywords internal
 result.Future <- function(future, ...) {
+  ## Has the result already been collected?
   result <- future$result
-  if (inherits(result, "FutureResult")) return(result)
+  if (!is.null(result)) {
+    if (inherits(result, "FutureError")) stop(result)
+    return(result)
+  }
   
   if (future$state == "created") {
     future <- run(future)
@@ -367,7 +371,7 @@ value.Future <- function(future, signal = TRUE, ...) {
   }
 
   result <- result(future)
-  stopifnot(inherits(result, "FutureResult"))
+  stop_if_not(inherits(result, "FutureResult"))
 
   value <- result$value
   condition <- result$condition
@@ -448,13 +452,43 @@ getExpression.Future <- function(future, mc.cores = NULL, ...) {
                           sQuote(version)))
   }
 
+
+  enter <- bquote({
+    ## covr: skip=4
+    ## If 'future' is not installed on the worker, or a too old version
+    ## of 'future' is used, then give an early error
+    ## If future::FutureResult does not exist, give an error
+    has_future <- requireNamespace("future", quietly = TRUE)
+    version <- if (has_future) packageVersion("future") else NULL
+    if (!has_future || version < "1.8.0") {
+      info <- c(
+        r_version = gsub("R version ", "", R.version$version.string),
+        platform = sprintf("%s (%s-bit)",
+                           R.version$platform, 8 * .Machine$sizeof.pointer),
+        os = paste(Sys.info()[c("sysname", "release", "version")],
+                   collapse = " "),
+        hostname = Sys.info()[["nodename"]]
+      )
+      info <- sprintf("%s: %s", names(info), info)
+      info <- paste(info, collapse = "; ")
+      if (!has_future) {
+        msg <- sprintf("Package 'future' is not installed on worker (%s)", info)
+      } else {
+        msg <- sprintf("Package 'future' on worker (%s) must be of version >= 1.8.0: %s", info, version)
+      }
+      stop(msg)
+    }
+  })
+  exit <- NULL
+  
   ## Should 'mc.cores' be set?
   if (!is.null(mc.cores)) {
 ##    mdebug("getExpression(): setting mc.cores = %d inside future", mc.cores)
     ## FIXME: How can we guarantee that '...future.mc.cores.old'
     ## is not overwritten?  /HB 2016-03-14
     enter <- bquote({
-      ## covr: skip=2
+      ## covr: skip=3
+      .(enter)
       ...future.mc.cores.old <- getOption("mc.cores")
       options(mc.cores = .(mc.cores))
     })
@@ -463,10 +497,8 @@ getExpression.Future <- function(future, mc.cores = NULL, ...) {
       ## covr: skip=1
       options(mc.cores = ...future.mc.cores.old)
     })
-  } else {
-    enter <- exit <- NULL
   }
-
+  
   ## Seed RNG seed?
   if (!is.null(future$seed)) {
     enter <- bquote({
@@ -481,7 +513,7 @@ getExpression.Future <- function(future, mc.cores = NULL, ...) {
 
   ## Reset future strategies upon exit of future
   strategies <- plan("list")
-  stopifnot(length(strategies) >= 1L)
+  stop_if_not(length(strategies) >= 1L)
   exit <- bquote({
     ## covr: skip=2
     .(exit)
@@ -608,13 +640,20 @@ makeExpression <- function(expr, local = TRUE, globals.onMissing = getOption("fu
         .(exit)
       })
     })
-  } else if (version == "1.8") {
+  } else if (version == "1.8") {    
     expr <- bquote({
       ## covr: skip=6
       .(enter)
       tryCatch({
         ...future.value <- .(expr)
-        future::FutureResult(value = ...future.value)
+        ## A FutureResult object (without requiring the future package)
+#       structure(list(
+#          value = ...future.value,
+#          condition = NULL,
+#          calls = NULL,
+#          version = "1.8"
+#       ), class = c("FutureResult", "list"))
+        future::FutureResult(value = ...future.value, version = "1.8")
       }, error = function(cond) {
         calls <- sys.calls()
         ## Drop fluff added by tryCatch()
@@ -622,8 +661,13 @@ makeExpression <- function(expr, local = TRUE, globals.onMissing = getOption("fu
         ## Drop fluff added by outer tryCatch()
   #      calls <- calls[-seq_len(current+7L)]
         ## Drop fluff added by outer local = TRUE
-  #      if (future$local) calls <- calls[-seq_len(6L)]
-        future::FutureResult(value = NULL, condition = cond, calls = calls)
+        #      if (future$local) calls <- calls[-seq_len(6L)]
+        structure(list(
+          value = NULL,
+          condition = cond,
+          calls = calls,
+          version = "1.8"
+        ), class = "FutureResult")
       }, finally = {
         .(exit)
       })
@@ -647,5 +691,3 @@ packages <- function(future, ...) UseMethod("packages")
 packages.Future <- function(future, ...) {
   future[["packages"]]
 }
-
-
