@@ -92,13 +92,18 @@ resolved.MulticoreFuture <- function(x, timeout = 0.2, ...) {
 
   selectChildren <- importParallel("selectChildren")
   job <- x$job
-  stopifnot(inherits(job, "parallelJob"))
+  stop_if_not(inherits(job, "parallelJob"))
 
   ## NOTE: We cannot use mcollect(job, wait = FALSE, timeout = 0.2),
   ## because that will return NULL if there's a timeout, which is
   ## an ambigous value because the future expression may return NULL.
   ## WORKAROUND: Adopted from parallel::mccollect().
-  pid <- selectChildren(job, timeout = timeout)
+  ## WORKAROUND 2: In R (>= 3.5.0) the below call to selectChildren() produces
+  ## warnings such as "cannot wait for child 13206 as it does not exist", cf.
+  ## https://github.com/HenrikBengtsson/future/issues/218.
+  ## For now, we're suppressing those warnings until the underlying problem 
+  ## is fully understood and fixed. /HB 2018-05-01
+  pid <- suppressWarnings(selectChildren(job, timeout = timeout))
   res <- (is.integer(pid) || is.null(pid))
 
   ## Signal conditions early? (happens only iff requested)
@@ -110,9 +115,12 @@ resolved.MulticoreFuture <- function(x, timeout = 0.2, ...) {
 
 #' @export
 result.MulticoreFuture <- function(future, ...) {
-  ## Has the value already been collected?
+  ## Has the result already been collected?
   result <- future$result
-  if (!is.null(result)) return(result)
+  if (!is.null(result)) {
+    if (inherits(result, "FutureError")) stop(result)
+    return(result)
+  }
 
   if (future$state == "created") {
     future <- run(future)
@@ -126,27 +134,36 @@ result.MulticoreFuture <- function(future, ...) {
   ## then collect and record the value
   mccollect <- importParallel("mccollect")
   job <- future$job
-  stopifnot(inherits(job, "parallelJob"))
-  result <- mccollect(job, wait = TRUE)[[1L]]
+  stop_if_not(inherits(job, "parallelJob"))
+  ## WORKAROUND: Pass single job as list, cf.
+  ## https://bugs.r-project.org/bugzilla3/show_bug.cgi?id=17413
+  ## WORKAROUND 2: In R (>= 3.5.0) the below call to selectChildren() produces
+  ## warnings such as "cannot wait for child 13206 as it does not exist", cf.
+  ## https://github.com/HenrikBengtsson/future/issues/218.
+  ## For now, we're suppressing those warnings until the underlying problem 
+  ## is fully understood and fixed. /HB 2018-05-01
+  result <- suppressWarnings(mccollect(jobs = list(job), wait = TRUE))[[1L]]
 
   ## Sanity checks
   if (!inherits(result, "FutureResult")) {
-    label <- future$label
-    if (is.null(label)) label <- "<none>"
-    
     ## SPECIAL: Check for fallback 'fatal error in wrapper code'
     ## try-error from parallel:::mcparallel().  If detected, then
     ## turn into an error with a more informative error message, cf.
     ## https://github.com/HenrikBengtsson/future/issues/35
     if (identical(result, structure("fatal error in wrapper code", class = "try-error"))) {
+      label <- future$label
+      if (is.null(label)) label <- "<none>"
       msg <- result
-      stop(FutureError(sprintf("Detected an error (%s) by the 'parallel' package while trying to retrieve the value of a %s (%s). This could be because the forked R process that evaluates the future was terminated before it was completed: %s", sQuote(msg), class(future)[1], sQuote(label), sQuote(hexpr(future$expr))), future = future))
+      ex <- FutureError(sprintf("Detected an error (%s) by the 'parallel' package while trying to retrieve the value of a %s (%s). This could be because the forked R process that evaluates the future was terminated before it was completed: %s", sQuote(msg), class(future)[1], sQuote(label), sQuote(hexpr(future$expr))), future = future)
+    } else {
+      ex <- UnexpectedFutureResultError(future)
     }
-    
-    stop(FutureError(sprintf("Internal error: Unexpected result retrieved for %s future (%s): %s", class(future)[1], sQuote(label), sQuote(hexpr(future$expr))), future = future))
+    future$result <- ex
+    stop(ex)
   }
   
   future$result <- result
+  
   ## BACKWARD COMPATIBILITY
   future$state <- if (inherits(result$condition, "error")) "failed" else "finished"
 
@@ -161,3 +178,8 @@ result.MulticoreFuture <- function(future, ...) {
 getExpression.MulticoreFuture <- function(future, mc.cores = 1L, ...) {
   NextMethod("getExpression", mc.cores = mc.cores)
 }
+
+
+select_children <- function(children, timeout = 0) {
+  selectChildren <- importParallel("selectChildren")
+}
