@@ -84,8 +84,12 @@ run.UniprocessFuture <- function(future, ...) {
 
 #' @export
 result.UniprocessFuture <- function(future, ...) {
+  ## Has the result already been collected?
   result <- future$result
-  if (inherits(result, "FutureResult")) return(result)
+  if (!is.null(result)) {
+    if (inherits(result, "FutureError")) stop(result)
+    return(result)
+  }
   
   if (future$state == "created") {
     run(future)
@@ -94,9 +98,9 @@ result.UniprocessFuture <- function(future, ...) {
   result <- future$result
   if (inherits(result, "FutureResult")) return(result)
 
-  label <- future$label
-  if (is.null(label)) label <- "<none>"
-  stop(FutureError(sprintf("Internal error: Unexpected result retrieved for %s future (%s): %s", class(future)[1], sQuote(label), sQuote(hexpr(future$expr))), future = future))
+  ex <- UnexpectedFutureResultError(future)
+  future$result <- ex
+  stop(ex)
 }
 
 
