@@ -47,9 +47,14 @@ makeClusterPSOCK <- function(workers, makeNode = makeNodePSOCK, port = c("auto",
   if (is.character(port)) {
     port <- match.arg(port)
     if (identical(port, "auto")) {
-      port <- Sys.getenv("R_PARALLEL_PORT", NA_character_)
-      port <- as.integer(port)
-      if (is.na(port)) port <- 11000:11999
+      port0 <- Sys.getenv("R_PARALLEL_PORT")
+      port <- suppressWarnings(as.integer(port0))
+      if (is.na(port)) {
+        if (nzchar(port0)) {
+          warning("Non-numeric value of environment variable 'R_PARALLEL_PORT' coerced to NA_integer_: ", sQuote(port0))
+        }
+        port <- 11000:11999
+      }
     } else if (identical(port, "random")) {
       port <- 11000:11999
     }
@@ -181,8 +186,12 @@ makeClusterPSOCK <- function(workers, makeNode = makeNodePSOCK, port = c("auto",
 #' on the \code{PATH}.  It is less common to find this command on Windows
 #' system, which are more likely to have the \command{PuTTY} software and
 #' its SSH client \command{plink} installed.
-#' If neither \command{ssh} nor \command{plink} is found, an informative error
-#' message is produced.
+#' Furthermore, when running \R from RStudio on Windows, the \command{ssh}
+#' client that is distributed with RStudio will be used as a fallback if
+#' neither of the above two commands are available on the \code{PATH}.
+#' Note that on Windows 10, there is a beta version of OpenSSH that can
+#' be enabled in the Windows Settings, cf. \url{https://www.thomasmaurer.ch/2017/11/install-ssh-on-windows-10-as-optional-feature/}.
+#' If no SSH-client is found, an informative error message is produced.
 #' It is also possible to specify the absolute path to the SSH client.  To do
 #' this for PuTTY, specify the absolute path in the first element and option
 #' \command{-ssh} in the second as in
@@ -202,7 +211,7 @@ makeClusterPSOCK <- function(workers, makeNode = makeNodePSOCK, port = c("auto",
 #' The default is to use reverse SSH tunneling (\code{revtunnel = TRUE}) for
 #' workers running on other machines.  This avoids the complication of
 #' otherwise having to configure port forwarding in firewalls, which often
-#' requires static IP address as well as privilieges to edit the firewall,
+#' requires static IP address as well as privileges to edit the firewall,
 #' something most users don't have.
 #' It also has the advantage of not having to know the internal and / or the
 #' public IP address / hostname of the master.
@@ -211,16 +220,16 @@ makeClusterPSOCK <- function(workers, makeNode = makeNodePSOCK, port = c("auto",
 #' on some systems, e.g. compute clusters.
 #'
 #' @section Default value of argument \code{rscript}:
-#' If \code{homogenenous} is FALSE, the \code{rscript} defaults to
+#' If \code{homogeneous} is FALSE, the \code{rscript} defaults to
 #' \code{"Rscript"}, i.e. it is assumed that the \command{Rscript} executable
 #' is available on the \code{PATH} of the worker.
-#' If \code{homogenenous} is TRUE, the \code{rscript} defaults to
+#' If \code{homogeneous} is TRUE, the \code{rscript} defaults to
 #' \code{file.path(R.home("bin"), "Rscript")}, i.e. it is basically assumed
 #' that the worker and the caller share the same file system and R installation.
 #' 
 #' @section Default value of argument \code{homogeneous}:
-#' The default value of \code{homogenenous} is TRUE if and only if either
-#' of the following is fullfilled:
+#' The default value of \code{homogeneous} is TRUE if and only if either
+#' of the following is fulfilled:
 #' \itemize{
 #'  \item \code{worker} is \emph{localhost}
 #'  \item \code{revtunnel} is FALSE and \code{master} is \emph{localhost}
@@ -257,21 +266,21 @@ makeNodePSOCK <- function(worker = "localhost", master = NULL, port, connectTime
   }
 
   manual <- as.logical(manual)
-  stopifnot(length(manual) == 1L, !is.na(manual))
+  stop_if_not(length(manual) == 1L, !is.na(manual))
 
   dryrun <- as.logical(dryrun)
-  stopifnot(length(dryrun) == 1L, !is.na(dryrun))
+  stop_if_not(length(dryrun) == 1L, !is.na(dryrun))
   
   ## Locate a default SSH client?
   if (!is.null(rshcmd)) {
     rshcmd <- as.character(rshcmd)
-    stopifnot(length(rshcmd) >= 1L)
+    stop_if_not(length(rshcmd) >= 1L)
   }
 
   rshopts <- as.character(rshopts)
   
   user <- as.character(user)
-  stopifnot(length(user) <= 1L)
+  stop_if_not(length(user) <= 1L)
   
   port <- as.integer(port)
   if (is.na(port) || port < 0L || port > 65535L) {
@@ -279,7 +288,7 @@ makeNodePSOCK <- function(worker = "localhost", master = NULL, port, connectTime
   }
 
   revtunnel <- as.logical(revtunnel)
-  stopifnot(length(revtunnel) == 1L, !is.na(revtunnel))
+  stop_if_not(length(revtunnel) == 1L, !is.na(revtunnel))
   
   if (is.null(master)) {
     if (localMachine || revtunnel) {
@@ -288,13 +297,13 @@ makeNodePSOCK <- function(worker = "localhost", master = NULL, port, connectTime
       master <- Sys.info()[["nodename"]]
     }
   }
-  stopifnot(!is.null(master))
+  stop_if_not(!is.null(master))
 
   timeout <- as.numeric(timeout)
-  stopifnot(length(timeout) == 1L, !is.na(timeout), is.finite(timeout), timeout >= 0)
+  stop_if_not(length(timeout) == 1L, !is.na(timeout), is.finite(timeout), timeout >= 0)
   
   methods <- as.logical(methods)
-  stopifnot(length(methods) == 1L, !is.na(methods))
+  stop_if_not(length(methods) == 1L, !is.na(methods))
  
   if (is.null(homogeneous)) {
     homogeneous <- {
@@ -304,28 +313,28 @@ makeNodePSOCK <- function(worker = "localhost", master = NULL, port, connectTime
     }
   }
   homogeneous <- as.logical(homogeneous)
-  stopifnot(length(homogeneous) == 1L, !is.na(homogeneous))
+  stop_if_not(length(homogeneous) == 1L, !is.na(homogeneous))
 
   if (is.null(rscript)) {
     rscript <- "Rscript"
     if (homogeneous) rscript <- file.path(R.home("bin"), rscript)
   }
   rscript <- as.character(rscript)
-  stopifnot(length(rscript) >= 1L)
+  stop_if_not(length(rscript) >= 1L)
 
   rscript_args <- as.character(rscript_args)
 
   useXDR <- as.logical(useXDR)
-  stopifnot(length(useXDR) == 1L, !is.na(useXDR))
+  stop_if_not(length(useXDR) == 1L, !is.na(useXDR))
 
   renice <- as.integer(renice)
-  stopifnot(length(renice) == 1L)
+  stop_if_not(length(renice) == 1L)
 
   rank <- as.integer(rank)
-  stopifnot(length(rank) == 1L, !is.na(rank))
+  stop_if_not(length(rank) == 1L, !is.na(rank))
   
   verbose <- as.logical(verbose)
-  stopifnot(length(verbose) == 1L, !is.na(verbose))
+  stop_if_not(length(verbose) == 1L, !is.na(verbose))
 
   ## .slaveRSOCK() command already specified?
   if (!any(grepl("parallel:::.slaveRSOCK()", rscript_args, fixed = TRUE))) {
@@ -351,7 +360,7 @@ makeNodePSOCK <- function(worker = "localhost", master = NULL, port, connectTime
 
   ## Renice?
   if (!is.na(renice) && renice > 0L) {
-    cmd <- sprintf("nice +%d %s", renice, cmd)
+    cmd <- sprintf("nice --adjustment=%d %s", renice, cmd)
   }
 
   if (!localMachine) {
@@ -371,7 +380,7 @@ makeNodePSOCK <- function(worker = "localhost", master = NULL, port, connectTime
   } else {
     local_cmd <- cmd
   }
-  stopifnot(length(local_cmd) == 1L)
+  stop_if_not(length(local_cmd) == 1L)
   
   if (manual || dryrun) {
     msg <- c("----------------------------------------------------------------------", sprintf("Manually start worker #%s on %s with:", rank, sQuote(worker)), sprintf("  %s", cmd))
@@ -421,7 +430,7 @@ makeNodePSOCK <- function(worker = "localhost", master = NULL, port, connectTime
 ## 'closeAllConnections() can really mess things up' on 2016-10-30
 ## (https://stat.ethz.ch/pipermail/r-devel/2016-October/073331.html)
 add_cluster_uuid <- function(cl) {
-  stopifnot(inherits(cl, "cluster"))
+  stop_if_not(inherits(cl, "cluster"))
   
   for (ii in seq_along(cl)) {
     node <- cl[[ii]]
@@ -468,7 +477,7 @@ is_localhost <- local({
       return(NA)
     }
     
-    stopifnot(length(worker) == 1, length(hostname) == 1)
+    stop_if_not(length(worker) == 1, length(hostname) == 1)
   
     ## Already known to a localhost or not to one?
     if (worker %in% localhosts) return(TRUE)
@@ -523,16 +532,36 @@ is_fqdn <- function(worker) {
 
 ## Locate an SSH client
 find_rshcmd <- function(must_work = TRUE) {
-  cmds <- list("ssh", c("plink", "-ssh"))
-  for (cmd in cmds) {
-    if (nzchar(Sys.which(cmd[1]))) return(cmd)
+  cmd_calls <- list(
+    "ssh",
+    c("plink", "-ssh")
+  )
+  for (cmd_call in cmd_calls) {
+    cmd <- cmd_call[1]
+    cmd_bin <- Sys.which(cmd)
+    if (nzchar(cmd_bin)) return(c(cmd_bin, cmd_call[-1]))
+  }
+
+  ## FALLBACK: On Windows, RStudio distributes an 'ssh.exe' client
+  if (.Platform$OS.type == "windows") {
+    path <- Sys.getenv("RSTUDIO_MSYS_SSH")
+    if (file_test("-d", path)) {
+      path <- normalizePath(path)
+      path_org <- Sys.getenv("PATH")
+      on.exit(Sys.setenv(PATH = path_org))
+      ## Append RSTUDIO_MSYS_SSH with the rationale that it
+      ## emulates how RStudio's 'Tools -> Shell ...' is set up.
+      Sys.setenv(PATH = file.path(path_org, path, fsep = ";"))
+      cmd_bin <- Sys.which("ssh")
+      if (nzchar(cmd_bin)) return(cmd_bin)
+    }
   }
   
-  cmds_checked <- unlist(lapply(cmds, FUN = function(x) x[1]))
+  cmds_checked <- unlist(lapply(cmd_calls, FUN = function(x) x[1]))
   msg <- sprintf("Failed to locate a default SSH client (checked: %s). Please specify one via argument 'rshcmd'.", paste(sQuote(cmds_checked), collapse = ", ")) #nolint
   if (must_work) stop(msg)
 
-  cmd <- cmds[[1]]
+  cmd <- cmd_calls[[1]]
   msg <- sprintf("%s Will use %s.", msg, sQuote(paste(cmd, collapse = " ")))
   warning(msg)
   cmd
@@ -549,7 +578,7 @@ session_info <- function() {
 
 
 add_cluster_session_info <- function(cl) {
-  stopifnot(inherits(cl, "cluster"))
+  stop_if_not(inherits(cl, "cluster"))
   
   for (ii in seq_along(cl)) {
     node <- cl[[ii]]
@@ -562,7 +591,7 @@ add_cluster_session_info <- function(cl) {
     pid <- as.integer(gsub(".* ", "", pid))
     
     info <- clusterCall(cl[ii], fun = session_info)[[1]]
-    stopifnot(info$process$pid == pid)
+    stop_if_not(info$process$pid == pid)
     node$session_info <- info
     cl[[ii]] <- node
   }
