@@ -21,5 +21,5 @@
   on.exit(plan(oplan, substitute = FALSE, .call = NULL, .cleanup = FALSE, .init = FALSE))
   plan(strategy, substitute = FALSE, .call = NULL, .cleanup = FALSE, .init = FALSE)
 
-  eval(fassignment, envir = envir)
+  eval(fassignment, envir = envir, enclos = baseenv())
 }
