@@ -21,7 +21,8 @@
 remote <- function(expr, envir = parent.frame(), substitute = TRUE, lazy = FALSE, seed = NULL, globals = TRUE, persistent = TRUE, workers = NULL, user = NULL, revtunnel = TRUE, gc = FALSE, earlySignal = FALSE, myip = NULL, label = NULL, ...) {
   if (substitute) expr <- substitute(expr)
 
-  stopifnot(length(workers) >= 1L, !anyNA(workers))
+  if (is.function(workers)) workers <- workers()
+  stop_if_not(length(workers) >= 1L, !anyNA(workers))
 
   if (is.character(workers)) {
     homogeneous <- FALSE ## Calls plain 'Rscript'
@@ -53,7 +54,7 @@ remote <- function(expr, envir = parent.frame(), substitute = TRUE, lazy = FALSE
         myip <- "<external>"
       }
     }
-    stopifnot(length(myip) == 1, is.character(myip), !is.na(myip))
+    stop_if_not(length(myip) == 1, is.character(myip), !is.na(myip))
     
     if (myip == "<external>") {
       myip <- myExternalIP()
