@@ -71,9 +71,29 @@ for (cores in 1:availCores) {
   print(res)
   stopifnot(inherits(res, "try-error"))
 
+  ## Custom error class
+  f <- multisession({
+    stop(structure(list(message = "boom"),
+                   class = c("MyError", "error", "condition")))
+  })
+  print(f)
+  v <- value(f, signal = FALSE)
+  print(v)
+  stopifnot(inherits(v, "error"))
+  ## FIXME: Related to Issue #200
+  ## https://github.com/HenrikBengtsson/Wishlist-for-R/issues/57
+  ## stopifnot(inherits(v, "MyError"))
+
+  ## Make sure error is signaled
+  res <- tryCatch(value(f), error = identity)
+  stopifnot(inherits(res, "error"))
+
+  ## Issue #200: Custom condition class attributes are lost
+  ## https://github.com/HenrikBengtsson/Wishlist-for-R/issues/57
+  ## stopifnot(inherits(res, "MyError"))    
 
   message("*** multisession() - too large globals ...")
-  ooptsT <- options(future.globals.maxSize = 1024 * 4L)
+  ooptsT <- options(future.globals.maxSize = object.size(1:1014))
 
   limit <- getOption("future.globals.maxSize")
   cat(sprintf("Max total size of globals: %g bytes\n", limit))
@@ -95,7 +115,7 @@ for (cores in 1:availCores) {
 
 
     ## A too large object
-    a <- 1:1019 ## also on 32-bit platforms
+    a <- 1:1015
     yTruth <- sum(a)
     size <- object.size(a)
     cat(sprintf("a: %g bytes\n", size))
